@@ -15,12 +15,12 @@
 import functools
 import json
 import logging
+from unittest import mock
 import uuid
 
 import fixtures
 from keystoneauth1 import session
 from keystoneauth1 import token_endpoint
-import mock
 from oslo_utils import encodeutils
 import requests
 from requests_mock.contrib import fixture
@@ -216,7 +216,11 @@ class TestClient(testtools.TestCase):
 
     def test_headers_encoding(self):
         value = u'ni\xf1o'
-        headers = {"test": value, "none-val": None, "Name": "value"}
+        fake_location = b'http://web_server:80/images/fake.img'
+        headers = {"test": value,
+                   "none-val": None,
+                   "Name": "value",
+                   "x-image-meta-location": fake_location}
         encoded = http.encode_headers(headers)
         # Bug #1766235: According to RFC 8187, headers must be
         # encoded as 7-bit ASCII, so expect to see only displayable
@@ -225,6 +229,8 @@ class TestClient(testtools.TestCase):
         self.assertNotIn("none-val", encoded)
         self.assertNotIn(b"none-val", encoded)
         self.assertEqual(b"value", encoded[b"Name"])
+        # Bug #1788942: Colons in URL should not get percent-encoded
+        self.assertEqual(fake_location, encoded[b"x-image-meta-location"])
 
     @mock.patch('keystoneauth1.adapter.Adapter.request')
     def test_http_duplicate_content_type_headers(self, mock_ksarq):
@@ -361,11 +367,11 @@ class TestClient(testtools.TestCase):
         self.assertTrue(mock_log.called, 'LOG.debug never called')
         self.assertTrue(mock_log.call_args[0],
                         'LOG.debug called with no arguments')
-        hd_regex = ".*\s-H\s+'\s*%s\s*:\s*%s\s*'.*" % (hd_name, hd_val)
+        hd_regex = r".*\s-H\s+'\s*%s\s*:\s*%s\s*'.*" % (hd_name, hd_val)
         self.assertThat(mock_log.call_args[0][0],
                         matchers.MatchesRegex(hd_regex),
                         'header not found in curl command')
-        body_regex = ".*\s-d\s+'%s'\s.*" % body
+        body_regex = r".*\s-d\s+'%s'\s.*" % body
         self.assertThat(mock_log.call_args[0][0],
                         matchers.MatchesRegex(body_regex),
                         'body not found in curl command')
@@ -384,12 +390,12 @@ class TestClient(testtools.TestCase):
         needles = {'key': key, 'cert': cert, 'cacert': cacert}
         for option, value in needles.items():
             if value:
-                regex = ".*\s--%s\s+('%s'|%s).*" % (option, value, value)
+                regex = r".*\s--%s\s+('%s'|%s).*" % (option, value, value)
                 self.assertThat(mock_log.call_args[0][0],
                                 matchers.MatchesRegex(regex),
                                 'no --%s option in curl command' % option)
             else:
-                regex = ".*\s--%s\s+.*" % option
+                regex = r".*\s--%s\s+.*" % option
                 self.assertThat(mock_log.call_args[0][0],
                                 matchers.Not(matchers.MatchesRegex(regex)),
                                 'unexpected --%s option in curl command' %
@@ -415,7 +421,7 @@ class TestClient(testtools.TestCase):
         self.assertTrue(mock_log.call_args[0],
                         'LOG.debug called with no arguments')
         self.assertThat(mock_log.call_args[0][0],
-                        matchers.MatchesRegex('.*\s-k\s.*'),
+                        matchers.MatchesRegex(r'.*\s-k\s.*'),
                         'no -k option in curl command')
 
     @mock.patch('glanceclient.common.http.LOG.debug')
